*************
API Reference
*************

..
   When sphinx 8.2 comes out, add `:no-index-entry:` to the `.. autoclass` and 
   `.. autofunction`` directives in the autosummary templates.

.. autosummary::
   :toctree: api
   :recursive:

   visible_residues.qualified.name
